@@ -16,6 +16,10 @@ Mesh::Mesh(std::vector<GLfloat> v, std::vector<GLuint> i)
 
 float Mesh::min(size_t start) const
 {
+    if (start >= vertices.size())
+    {
+        return -1;
+    }
     float v = vertices[start];
     for (size_t i=start; i < vertices.size(); i += 3)
     {
@@ -26,6 +30,10 @@ float Mesh::min(size_t start) const
 
 float Mesh::max(size_t start) const
 {
+    if (start >= vertices.size())
+    {
+        return 1;
+    }
     float v = vertices[start];
     for (size_t i=start; i < vertices.size(); i += 3)
     {
@@ -33,3 +41,8 @@ float Mesh::max(size_t start) const
     }
     return v;
 }
+
+bool Mesh::empty() const
+{
+    return vertices.size() == 0;
+}
